@@ -164,6 +164,21 @@ def test_success_payload():
         d.raise_for_status()
 
 
+def test_redirect_response():
+    @httmock.all_requests
+    def response_content(url, request):
+        return {
+            'status_code': 303,
+            'headers': {'Location': 'https://nosuch.example.com'},
+            'content': {'url': 'https://nosuch.example.com'},
+        }
+
+    with httmock.HTTMock(response_content):
+        d = subject.makeSingleHttpRequest('GET', 'http://www.example.com', None, {})
+        assert d.json() == {'url': 'https://nosuch.example.com'}
+        assert d.status_code == 303
+
+
 def test_failure():
     @httmock.all_requests
     def response_content(url, requet):
@@ -383,6 +398,15 @@ def clear_env(self):
         os.environ['TASKCLUSTER_ROOT_URL'] = 'https://tc.example.com'
         assert subject.optionsFromEnvironment({'rootUrl': 'https://other.example.com'}) == {'rootUrl': 'https://tc.example.com'}
 
+    @mock.patch.dict(os.environ)
+    def test_normalized_rooturl(self):
+        """
+        If the environment contains a URL with a trailing slash,
+        it is normalized by `optionsFromEnvironment`.
+        """
+        os.environ['TASKCLUSTER_ROOT_URL'] = 'https://tc.test/'
+        assert subject.optionsFromEnvironment() == {'rootUrl': 'https://tc.test'}
+
     @mock.patch.dict(os.environ)
     def test_default_creds(self):
         os.environ['TASKCLUSTER_ROOT_URL'] = 'https://tc.example.com'
